#!/bin/bash

if ! command -v curl >/dev/null 2>&1
then
    echo "curl not installed. Please install and try again. No log levels changed."
    exit 1
fi

echo "Current envoy log level"
curl --location --request POST 'http://localhost:9901/logging'

read -p "Enter envoy log level to change to [0 - Default (Info), 1 - Debug, 2 - No Change]: "  EnvoyLogLevel
echo -e "\n"

read -p "Enter package of SGW Mgmt service for log level change [com.vmware]: " SGWMgmtPackage
SGWMgmtPackage=${SGWMgmtPackage:-com.vmware}
echo "Current SGW Mgmt service log level for package $SGWMgmtPackage:"
curl --location --request GET "http://localhost:8080/v1/actuator/loggers/$SGWMgmtPackage"
echo -e "\n"
read -p "Enter SGW Mgmt service log level to change to for $SGWMgmtPackage package [0 - Default (Info), 1 - Debug, 2 - No Change]: "  SGWMgmtLogLevel
echo -e "\n"

case "$EnvoyLogLevel" in
  "0")
    echo "Changing envoy log level to default (info)"
    curl --location --request POST 'http://localhost:9901/logging?level=info'
  ;;
  "1")
    echo "Changing envoy log level to debug"
    curl --location --request POST 'http://localhost:9901/logging?level=debug'
  ;;
  "2")
    echo "Not changing envoy log level"
  ;;
  *)
    echo "Invalid envoy log level passed, not changing it"
  ;;
esac

case "$SGWMgmtLogLevel" in
  "0")
    echo "Changing SGW Mgmt log level for package $SGWMgmtPackage to default (info)"
    curl --location --request POST "http://localhost:8080/v1/actuator/loggers/$SGWMgmtPackage" \
    --header 'Content-Type: application/json' \
    --data-raw '{
        "configuredLevel": "INFO"
    }'
    curl --location --request GET "http://localhost:8080/v1/actuator/loggers/$SGWMgmtPackage"
  ;;
  "1")
    echo "Changing SGW Mgmt log level for package $SGWMgmtPackage to debug"
    curl --location --request POST "http://localhost:8080/v1/actuator/loggers/$SGWMgmtPackage" \
    --header 'Content-Type: application/json' \
    --data-raw '{
        "configuredLevel": "DEBUG"
    }'
    curl --location --request GET "http://localhost:8080/v1/actuator/loggers/$SGWMgmtPackage"
  ;;
  "2")
    echo "Not changing SGW Mgmt service log level for package $SGWMgmtPackage"
  ;;
  *)
    echo "Invalid SGW Mgmt log level passed, not changing it"
  ;;
esac

echo -e "\n"
