set CERTFILE=%DATA_HOME%\certs\sgw_certificate.pem
set CHAINFILE=%DATA_HOME%\certs\sgw_chain.pem

SET OCSP_RESPONSE=%DATA_HOME%\certs\good_ocsp_resp.der
SET JAVA_SERVICE_LOG=%DATA_HOME%\logs\java_service_error.log
SET filesPresent=0
SET ocsp_responder_url=""
SET OCSP_CHECK_LOGFILE=%DATA_HOME%\logs\ocsp.log
echo ================================================= >> %OCSP_CHECK_LOGFILE%
echo %date% %time% >> %OCSP_CHECK_LOGFILE%

if exist %CERTFILE% ( if exist %CHAINFILE% ( SET filesPresent=1 ) )

IF %filesPresent% == 1 (
  openssl x509 -noout -ocsp_uri -in %CERTFILE% > ocsp_endpoint.txt
  SET /p ocsp_responder_url=< ocsp_endpoint.txt
) ELSE (
  echo "Certificate %CERTFILE% OR %CHAINFILE% is missing. Cannot generate OCSP response." >> %OCSP_CHECK_LOGFILE%
)

IF %ocsp_responder_url% == "" (
  SET ENVOY_CONFIG=%SGW_HOME%\config\envoy-config-win.yaml
  echo "No OCSP Responder Found, starting the server in Self Signed Mode.." >> %OCSP_CHECK_LOGFILE%
) ELSE (
  SET ENVOY_CONFIG=%SGW_HOME%\config\envoy-config-ocsp-win.yaml
  openssl ocsp -issuer %CHAINFILE% -cert %CERTFILE% -verify_other %CHAINFILE% -CAfile %CHAINFILE% -no_nonce -url %ocsp_responder_url% -respout %OCSP_RESPONSE%
)

echo "Running Command %ENVOY_HOME%\envoy.exe --log-path %DATA_HOME%\logs\envoy-system.log --config-path %ENVOY_CONFIG%" >> %OCSP_CHECK_LOGFILE%
echo ================================================= >> %OCSP_CHECK_LOGFILE%


setx API_ID %API_ID% /M
setx SENSOR_GATEWAY_ENTRY_POINT %SENSOR_GATEWAY_ENTRY_POINT% /M
setx SENSOR_GATEWAY_HOST_IP %SENSOR_GATEWAY_HOST_IP% /M
setx API_KEY %API_KEY% /M
setx CBC_URL %CBC_URL% /M
setx SGW_KEY_PWD %SGW_KEY_PWD% /M

sc create Envoy binpath= "\"%ENVOY_HOME%\envoy.exe\" --config-path \"%ENVOY_CONFIG%\" -l warn --log-path \"%DATA_HOME%\logs\envoy-system.log\""
sc start Envoy
sc failure Envoy reset= 3600  actions= restart/300/restart/300/run/300

SET filename=%SGW_HOME%\bin\ocsp_job.bat
schtasks /create /tn sensor-gateway-envoy /tr "cmd /c \"%filename%\"" /sc daily /st 00:00 /ru system

WinSW-x64.exe install "%SGW_HOME%"\config\sgw.xml
WinSW-x64.exe start "%SGW_HOME%"\config\sgw.xml

FOR /L %%N IN () DO (
	curl.exe http://localhost:8080/sgw/health_check
	IF NOT ERRORLEVEL 0 (
		echo ================================================= >> %JAVA_SERVICE_LOG%
		echo %date% %time% >> %JAVA_SERVICE_LOG%
		echo "Service is down. Please check sgw_service.log for more info. " >> %JAVA_SERVICE_LOG%
		echo ================================================= >> %JAVA_SERVICE_LOG%
		exit
	)
)
